BBox

Struct BBox 

pub struct BBox {
    pub west: f64,
    pub south: f64,
    pub east: f64,
    pub north: f64,
}
Bounding box struct

Fields

west: f64

west/left boundary

south: f64

south/bottom boundary

east: f64

east/right boundary

north: f64

north/top boundary

Implementations

Source

impl BBox

pub fn new(west: f64, south: f64, east: f64, north: f64) -> BBox

Create a new BBox

pub fn world_planet() -> BBox

Returns a bounding box that covers the entire world.

pub fn world_web() -> BBox

Returns a bounding box that covers the entire web mercator world.

pub fn clamp_web(&self) -> BBox

pub fn clamp(&self, o: &BBox) -> BBox

pub fn geo_wrap(&self) -> BBox

pub fn is_antimeridian(&self) -> bool

pub fn crosses_antimeridian(&self) -> bool

Returns true if the bounding box crosses the antimeridian (the 180-degree meridian).

pub fn tuple(&self) -> (f64, f64, f64, f64)

Returns the bounding box as a tuple

pub fn north(&self) -> f64

Returns the top/north boundary of the bounding box

pub fn south(&self) -> f64

Returns the bottom/south boundary of the bounding box

pub fn east(&self) -> f64

Returns the right/east boundary of the bounding box

pub fn west(&self) -> f64

Returns the left/west boundary of the bounding box

pub fn top(&self) -> f64

Returns the top/north boundary of the bounding box

pub fn bottom(&self) -> f64

Returns the bottom/south boundary of the bounding box

pub fn right(&self) -> f64

Returns the right/east boundary of the bounding box

pub fn left(&self) -> f64

Returns the left/west boundary of the bounding box

pub fn json_arr(&self) -> String

Returns the geojson tuple/array representation of the bounding box

pub fn projwin_str(&self) -> String

Returns the gdal-ish string representation of the bounding box

pub fn contains_lnglat(&self, lnglat: &LngLat) -> bool

Returns the center of the bounding box as a LngLat

pub fn contains_tile(&self, tile: &Tile) -> bool

Returns true if the current instance contains the given Tile

pub fn contains_bbox(&self, other: &BBox) -> bool

Returns true if the current instance contains the given BBox

pub fn contains(&self, other: &BBoxContainable) -> bool

Returns true if the current instance contains the given BBoxContainable object.

pub fn is_within(&self, other: &BBox) -> bool

Returns true if the current instance is within the given bounding box.

pub fn intersects(&self, other: &BBox) -> bool

Returns true if the current instance intersects with the given bounding box.

pub fn bboxes(&self) -> Vec<BBox>

Returns a vector of bounding boxes (BBox) associated with the current instance.

If the instance crosses the antimeridian (the 180-degree meridian), this function returns two BBox instances:

  • The first bounding box covers the area from the object’s western boundary to 180 degrees east.
  • The second bounding box covers the area from -180 degrees west to the object’s eastern boundary.

If the instance does not cross the antimeridian, the function returns a vector containing a single BBox that represents the current instance itself.

Returns

Vec<BBox>: A vector containing one BBox if the instance does not cross the antimeridian, or two BBoxes if it does.

Examples
use utiles_core::BBox;
let example = BBox::new(-10.0, -10.0, 10.0, 10.0);
let bboxes = example.bboxes();
assert_eq!(bboxes.len(), 1);

let bboxes_crosses = BBox::new(179.0, -89.0, -179.0, 89.0).bboxes();
assert_eq!(bboxes_crosses.len(), 2); // Split into two bounding boxes
pub fn ul(&self) -> LngLat

Return upper left corner of bounding box as LngLat

pub fn ur(&self) -> LngLat

Return upper right corner of bounding box as LngLat

pub fn lr(&self) -> LngLat

Return lower right corner of bounding box as LngLat

pub fn ll(&self) -> LngLat

Return lower left corner of bounding box as LngLat

pub fn mbt_bounds(&self) -> String

Mbt metadata bounds string