Tile

Struct Tile 

pub struct Tile {
    pub x: u32,
    pub y: u32,
    pub z: u8,
}
Tile X-Y-Z struct

Fields

x: u32

x value (column)

y: u32

y value (row – flipped in mbtiles)

z: u8

z value (zoom level)

Implementations

Source

impl Tile

pub fn new(x: u32, y: u32, z: u8) -> Tile

Create a new Tile without checking validity

pub fn try_new(x: u32, y: u32, z: u8) -> Result<Tile, UtilesCoreError>

Create a Tile with validity check

Errors

Returns an error if the tile is invalid (e.g. x or y >= 2^z)

pub fn new_checked(x: u32, y: u32, z: u8) -> Option<Tile>

Construct a tile with validity check - returns Option<Tile>

pub fn new_unchecked(x: u32, y: u32, z: u8) -> Tile

Construct a tile without any checking.

pub fn flip(&self) -> Tile

flip the y value (row) and return flipped tile

pub fn bounds(&self) -> (f64, f64, f64, f64)

Return bounds tuple (west, south, east, north) for the tile

pub fn from_row_major_id(id: u64) -> Tile

Return tile from row-major tile-id

pub fn from_rmid(id: u64) -> Tile

Return tile from row-major tile-id (alias for from_row_major_id)

pub fn fmt_zxy(&self, sep: Option<&str>) -> String

Return zxy string with optional separator (default is ‘/’)

pub fn fmt_zxy_ext(&self, ext: &str, sep: Option<&str>) -> String

Return zxy string with extension and optional separator (default is ‘/’)

Examples
use utiles_core::Tile;
let tile = Tile::new(1, 2, 3);
assert_eq!(tile.fmt_zxy_ext("png", Some("-")), "3-1-2.png");
assert_eq!(tile.fmt_zxy_ext("png", None), "3/1/2.png");
pub fn from_quadkey(quadkey: &str) -> Result<Tile, UtilesCoreError>

Convert quadkey string to Tile

Errors

Returns error on invalid quadkey (e.g. “1234” – oh no ‘4’ is invalid)

pub fn from_qk(qk: &str) -> Result<Tile, UtilesCoreError>

Convert quadkey string to Tile (alias for from_quadkey)

Errors

Returns error on invalid quadkey (e.g. “1234” – oh no ‘4’ is invalid)

pub fn from_json_obj(json: &str) -> Result<Tile, UtilesCoreError>

Return tile from json-object string (e.g. {"x": 1, "y": 2, "z": 3})

Errors

Returns error if serde parsing fails

Examples
use utiles_core::Tile;
let tile = Tile::from_json_obj(r#"{"x": 1, "y": 2, "z": 3}"#).unwrap();
assert_eq!(tile, Tile::new(1, 2, 3));
pub fn from_json_arr(json: &str) -> Result<Tile, UtilesCoreError>

Return tile from json-array string (e.g. [1, 2, 3])

Errors

Returns error if serde parsing fails

Examples
use utiles_core::Tile;
let tile = Tile::from_json_arr("[1, 2, 3]").unwrap();
assert_eq!(tile, Tile::new(1, 2, 3));
pub fn from_json(json: &str) -> Result<Tile, UtilesCoreError>

Return tile from json string either object or array

Errors

Returns error if serde parsing fails

Examples
use utiles_core::Tile;
let tile_from_obj = Tile::from_json(r#"{"x": 1, "y": 2, "z": 3}"#).unwrap();
assert_eq!(tile_from_obj, Tile::new(1, 2, 3));
let tile_from_arr = Tile::from_json(r#"[1, 2, 3]"#).unwrap();
assert_eq!(tile_from_arr, Tile::new(1, 2, 3));
pub fn from_json_loose(json: &str) -> Result<Tile, UtilesCoreError>

Return tile from json string either object or array

Errors

Returns error if unable to parse json string

pub fn quadkey(&self) -> String

Return the quadkey for the tile

pub fn qk(&self) -> String

Return the quadkey for the tile (alias for quadkey)

pub fn from_lnglat_zoom( lng: f64, lat: f64, zoom: u8, truncate: Option<bool>, ) -> Result<Tile, UtilesCoreError>

Return new Tile from given (lng, lat, zoom)

Errors

Returns an error if the conversion fails resulting in invalid tile

pub fn up(&self) -> Tile

Return the bounding box of the tile

pub fn down(&self) -> Tile

Return the tile to the bottom

pub fn left(&self) -> Tile

Return the tile to the left

pub fn right(&self) -> Tile

Return the tile to the right

pub fn up_left(&self) -> Tile

Return the tile to the top left

pub fn up_right(&self) -> Tile

Return the tile to the top right

pub fn down_left(&self) -> Tile

Return the tile to the bottom left

pub fn down_right(&self) -> Tile

Return the tile to the bottom right

pub fn children1(&self) -> [Tile; 4]

Return direct children

pub fn children(&self, zoom: Option<u8>) -> Vec<Tile>

Return the children tiles of the tile

pub fn children_zorder(&self, zoom: Option<u8>) -> Vec<Tile>

Return the children tiles of the tile

pub fn parent(&self, zoom: Option<u8>) -> Option<Tile>

Return the parent tile

pub fn siblings(&self) -> Vec<Tile>

Return sibling tiles that share the same parent tile (not neighbors)

pub fn feature( &self, opts: &FeatureOptions, ) -> Result<TileFeature, UtilesCoreError>

Return a TileFeature for the tile

Errors

Returns an error if the feature creation fails (which may be impossible [2024-08-14])

Source

impl Tile

pub fn pmtileid(&self) -> u64

Return pmtile-id for the tile

pub fn from_pmtileid(id: u64) -> Tile

Return tile from pmtile-id

pub fn from_pmid(id: u64) -> Tile

Return tile from pmtile-id (alias for from_pmtileid)

pub fn parent_pmtileid(&self) -> Option<u64>

Return the parent tile’s pmtile-id