pub struct Tile {
pub x: u32,
pub y: u32,
pub z: u8,
}Expand description
Tile X-Y-Z struct
Fields
x: u32x value (column)
y: u32y value (row – flipped in mbtiles)
z: u8z value (zoom level)
Implementations
Sourceimpl Tile
impl Tile
Sourcepub fn try_new(x: u32, y: u32, z: u8) -> Result<Tile, UtilesCoreError>
pub fn try_new(x: u32, y: u32, z: u8) -> Result<Tile, UtilesCoreError>
Create a Tile with validity check
Errors
Returns an error if the tile is invalid (e.g. x or y >= 2^z)
Sourcepub fn new_checked(x: u32, y: u32, z: u8) -> Option<Tile>
pub fn new_checked(x: u32, y: u32, z: u8) -> Option<Tile>
Construct a tile with validity check - returns Option<Tile>
Sourcepub fn bounds(&self) -> (f64, f64, f64, f64)
pub fn bounds(&self) -> (f64, f64, f64, f64)
Return bounds tuple (west, south, east, north) for the tile
Sourcepub fn from_row_major_id(id: u64) -> Tile
pub fn from_row_major_id(id: u64) -> Tile
Return tile from row-major tile-id
Sourcepub fn from_rmid(id: u64) -> Tile
pub fn from_rmid(id: u64) -> Tile
Return tile from row-major tile-id (alias for from_row_major_id)
Sourcepub fn fmt_zxy(&self, sep: Option<&str>) -> String
pub fn fmt_zxy(&self, sep: Option<&str>) -> String
Return zxy string with optional separator (default is ‘/’)
Sourcepub fn fmt_zxy_ext(&self, ext: &str, sep: Option<&str>) -> String
pub fn fmt_zxy_ext(&self, ext: &str, sep: Option<&str>) -> String
Return zxy string with extension and optional separator (default is ‘/’)
Examples
use utiles_core::Tile;
let tile = Tile::new(1, 2, 3);
assert_eq!(tile.fmt_zxy_ext("png", Some("-")), "3-1-2.png");
assert_eq!(tile.fmt_zxy_ext("png", None), "3/1/2.png");Sourcepub fn from_quadkey(quadkey: &str) -> Result<Tile, UtilesCoreError>
pub fn from_quadkey(quadkey: &str) -> Result<Tile, UtilesCoreError>
Convert quadkey string to Tile
Errors
Returns error on invalid quadkey (e.g. “1234” – oh no ‘4’ is invalid)
Sourcepub fn from_qk(qk: &str) -> Result<Tile, UtilesCoreError>
pub fn from_qk(qk: &str) -> Result<Tile, UtilesCoreError>
Convert quadkey string to Tile (alias for from_quadkey)
Errors
Returns error on invalid quadkey (e.g. “1234” – oh no ‘4’ is invalid)
Sourcepub fn from_json_obj(json: &str) -> Result<Tile, UtilesCoreError>
pub fn from_json_obj(json: &str) -> Result<Tile, UtilesCoreError>
Sourcepub fn from_json_arr(json: &str) -> Result<Tile, UtilesCoreError>
pub fn from_json_arr(json: &str) -> Result<Tile, UtilesCoreError>
Sourcepub fn from_json(json: &str) -> Result<Tile, UtilesCoreError>
pub fn from_json(json: &str) -> Result<Tile, UtilesCoreError>
Return tile from json string either object or array
Errors
Returns error if serde parsing fails
Examples
use utiles_core::Tile;
let tile_from_obj = Tile::from_json(r#"{"x": 1, "y": 2, "z": 3}"#).unwrap();
assert_eq!(tile_from_obj, Tile::new(1, 2, 3));
let tile_from_arr = Tile::from_json(r#"[1, 2, 3]"#).unwrap();
assert_eq!(tile_from_arr, Tile::new(1, 2, 3));Sourcepub fn from_json_loose(json: &str) -> Result<Tile, UtilesCoreError>
pub fn from_json_loose(json: &str) -> Result<Tile, UtilesCoreError>
Return tile from json string either object or array
Errors
Returns error if unable to parse json string
Sourcepub fn from_lnglat_zoom(
lng: f64,
lat: f64,
zoom: u8,
truncate: Option<bool>,
) -> Result<Tile, UtilesCoreError>
pub fn from_lnglat_zoom( lng: f64, lat: f64, zoom: u8, truncate: Option<bool>, ) -> Result<Tile, UtilesCoreError>
Return new Tile from given (lng, lat, zoom)
Errors
Returns an error if the conversion fails resulting in invalid tile
Sourcepub fn down_right(&self) -> Tile
pub fn down_right(&self) -> Tile
Return the tile to the bottom right
Sourcepub fn children_zorder(&self, zoom: Option<u8>) -> Vec<Tile>
pub fn children_zorder(&self, zoom: Option<u8>) -> Vec<Tile>
Return the children tiles of the tile
Sourcepub fn siblings(&self) -> Vec<Tile>
pub fn siblings(&self) -> Vec<Tile>
Return sibling tiles that share the same parent tile (not neighbors)
Sourcepub fn feature(
&self,
opts: &FeatureOptions,
) -> Result<TileFeature, UtilesCoreError>
pub fn feature( &self, opts: &FeatureOptions, ) -> Result<TileFeature, UtilesCoreError>
Return a TileFeature for the tile
Errors
Returns an error if the feature creation fails (which may be impossible [2024-08-14])